#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-Python.
# @File         : upload
# @Time         : 2019-08-29 11:53
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

"""
https://github.com/Jie-Yuan/keras-flask-deploy-webapp/blob/master/app.py
"""
import os
from sanic import response
import aiohttp
import random
from sanic import Sanic
from sanic.exceptions import NotFound
from sanic.response import html, json, redirect, text, file, file_stream
from sanic.request import Request, File

app = Sanic()



@app.route("/files", methods=['POST'])
async def post_json(request):

    test_file = request.files.get('file')
    print(test_file)

    file_parameters = {
        'body': test_file.body.decode('utf8'),
        'name': test_file.name,
        'type': test_file.type,
    }
    print(file_parameters)

    basepath = os.path.dirname(__file__)
    file_path = os.path.join(basepath, './', test_file.name)
    with open(file_path, 'wb') as f:
        f.write(test_file.body)

    return json({"received": True, "file_names": request.files.keys(), "test_file_parameters": file_parameters})



app.run(host="0.0.0.0", port=9000, debug=True, auto_reload=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : model_train
# @Time         : 2019-08-29 17:12
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from sklearn.preprocessing import MaxAbsScaler

X = [[1],[2],[3]]

model = MaxAbsScaler()

print(model.fit_transform(X))

import joblib
joblib.dump(model, './sklearn.MaxAbsScaler.demo')


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : demo2
# @Time         : 2019-11-18 17:40
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


# coding=utf8
from sanic import Sanic, response
import asyncio
import uvloop

app = Sanic('async demo')


async def task_sleep():
    print('sleep before')
    await asyncio.sleep(5)
    print('sleep after')


@app.route("/")
async def test(request):
    print(request.app.loop)
    myLoop = request.app.loop
    myLoop.create_task(task_sleep())
    # task = request.app.loop.create_task(task_sleep())
    return response.json({"hello": "zhangbiao"})


if __name__ == '__main__':
    app.run(host="127.0.0.1", port=8811)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : ann_search
# @Time         : 2020/11/5 4:04 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import requests
from functools import lru_cache
from iapp import App

app_ = App()
app = app_.app


@lru_cache(256)
def get_bert_vector(text):
    return requests.get(f"http://tql.algo.browser.miui.srv/bert/simbert?texts=['{text}']").json()['vectors']


def xindao_search(**kwargs):
    text = kwargs.get('text', '')
    topk = kwargs.get('topk', 5)
    return_ids = kwargs.get('return_ids', 0)

    query_embedding = get_bert_vector(text)
    body = {
        "query": {
            "bool": {
                "must": [
                    {
                        "vector": {
                            "embedding": {
                                "topk": topk,
                                "values": query_embedding,
                                "metric_type": "IP",
                                "params": {
                                    "nprobe": 1
                                }
                            }
                        }
                    }
                ]
            }
        },
        "fields": []
    }

    ann_url = f"http://xindao-ann-cl33103.c3.ingress.mice.cc.d.xiaomi.net/collections/demo/entities"

    r = requests.get(ann_url, json=body).json()
    if return_ids:
        return [i['id'] for i in r['data']['result'][0]]
    else:
        return r


app_.add_route('/xindao_search', xindao_search)

if __name__ == '__main__':
    app_.run(f"{app_.app_file_name(__file__)}", port=9955, debug=True, reload=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : scheduler
# @Time         : 2019-09-02 13:17
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 
import asyncio

from datetime import datetime, time, timedelta
from iapp.scheduler import SanicScheduler, task

import jieba
from iapp import App

app = App(debug=True)
scheduler = SanicScheduler(app.app, False)  # CST 非 UTC

c1 = {}
c2 = {}
c3 = {}


@task(timedelta(seconds=10))  # 实现初始化
def hello1(xx):
    c1['n'] = c1.get('n', 0) + 1

    print('c1:', c1)
    print("Hello, {0}".format(xx), datetime.now())


@task(timedelta(seconds=100), timedelta(seconds=1 if len(c2) == 0 else 10))  # 实现初始化
def hello2(xx):
    """Runs the function every 2 minutes after 10 seconds."""
    print('c2:', c2)
    c2['n'] = c2.get('n', 0) + 1
    print("Hello, {0}".format(xx), datetime.now())


@task(start=time(hour=16, minute=11))  # 实现初始化
def hello3(xx):
    """14:11再次调度，TODO:第二天 第三天是否还能调度？"""
    print(c3)
    c3['n'] = c3.get('n', 0) + 1
    print("Hello, {0}".format(xx), datetime.now())


# pred1 = lambda **kwargs: c1
# pred2 = lambda **kwargs: c2
# pred3 = lambda **kwargs: c3
#
# app.add_route("/f1", pred1, version="1")
# app.add_route("/f2", pred2, version="2")
# app.add_route("/f3", pred3, version="3")
#
# if __name__ == '__main__':
#     app.run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : do
# @Time         : 2019-11-20 17:52
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


import schedule
import time
import values


def job():
    values.set_value(time.ctime())
    print("I'm working...")


async def do(app):
    schedule.every(3).seconds.do(job)
    schedule.every().hour.do(job)
    schedule.every().day.at("10:30").do(job)
    schedule.every(5).to(10).minutes.do(job)
    schedule.every().monday.do(job)
    schedule.every().wednesday.at("13:15").do(job)
    schedule.every().minute.at(":17").do(job)

    while True:
        schedule.run_pending()
        time.sleep(1)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : App
# @Time         : 2019-08-08 10:26
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  :

import sys
import socket  # socket.SO_REUSEPORT = 15
from collections import OrderedDict
from traceback import format_exc  # https://www.cnblogs.com/klchang/p/4635040.html
from sanic import Sanic, response
import multiprocessing
import logging
from sanic.log import logger

gunicorn_logger = logging.getLogger('gunicorn.error')
logger.handlers = gunicorn_logger.handlers
logger.setLevel(gunicorn_logger.level)


class App(object):

    def __init__(self, debug=False, verbose=False, **kwargs):
        self.app = Sanic("SanicApp")
        # SanicScheduler(self.app, False)
        self.debug = True if socket.gethostname() == 'yuanjie-Mac.local' else debug
        self.verbose = verbose  # Request Params

    def run(self, host="0.0.0.0", port=8000, access_log=False, workers=1, **kwargs):
        self.app.run(host, port, self.debug, backlog=2048, access_log=access_log, workers=workers, **kwargs)

    def add_route(self, uri="/test", func=lambda x="test": x, methods="GET", main_key="Score", **kwargs):
        handler = self._handler(func, methods, main_key, **kwargs)

        # self.app.route(uri, frozenset({self.methods}))(self._handler(func, methods, version))
        self.app.add_route(handler, uri, frozenset({methods}))

    def _handler(self, func, methods, main_key, **kwargs):
        async def handler(request):
            """
            request.json: {'a': 1}

            request.args:  {'a': ['1']}
            request.args.get('a'): 1
            request.args.getgetlist('a'): ['1']
            """
            input = request.json if methods == 'POST' else request.args
            output = OrderedDict()

            try:
                output[main_key] = func(**input)
            except Exception as error:
                output['Predict Error'] = error
                output['Predict Error Plus'] = format_exc().strip()
                output['Score'] = 0
            finally:
                output.update(kwargs)

                if self.verbose:
                    output['Request Params'] = input

            return response.json(output)

        return handler


if __name__ == '__main__':
    import jieba
    import time

    f = lambda **kwargs: kwargs
    f1 = lambda **kwargs: kwargs['x'] + kwargs['y']
    f2 = lambda x=1, y=1: x - y
    f3 = lambda text='小米是家不错的公司': jieba.lcut(text)

    app = App(verbose=True)
    app.add_route("/", f, main_key='main_key', time=time.ctime())
    app.add_route("/f1", f1, version="1", time=time.time(), a=1, b=111)
    app.add_route("/f2", f2, version="2")
    app.add_route("/f3", f3, version="3")

    app.run(port=9955)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : meeting
# @Time         : 2019-08-15 14:14
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from sanic import Sanic
from sanic import response
from iapp.utils import Templates

app = Sanic(__name__)

templates_map = Templates().load()


@app.route('/meeting')
async def index(request):
    _ = await templates_map['meeting'].render_async(body="body")
    return response.html(_)


@app.route('/meeting', methods=['POST'])
async def meeting(request):
    print(request.form)
    _ = request.form
    name, project, progress = _['name'], _['project'], _['progress']
    text = "{}@{}: \n{}".format(project[0], name[0], progress[0])
    _ = await templates_map['meeting'].render_async(dic=text)
    return response.html(_)


app.run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-Python.
# @File         : demo
# @Time         : 2019-08-15 10:20
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from iapp import App
import time


app = App()

f1 = lambda **kwargs: 666
def f1(**kwargs):
    with open('./log.txt', 'a') as f:
        f.write("666\n")


with open('./log.txt') as f:
    n = len(list(f))

def f2(**kwargs):
    global n
    return n+1111111111

app.add_route("/f1", f1, time=time.ctime())
app.add_route("/f2", f2, time=time.ctime())

app.run()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : gunicorn
# @Time         : 2019-11-21 11:00
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 
# https://www.jianshu.com/p/fecf15ad0c9a
import os
import re
import multiprocessing
import gevent.monkey

gevent.monkey.patch_all()

dev = False if re.search('.c3_|.c4_', os.environ.get('DOCKER_JOBNAME', '')) else True
debug = reload = dev
bind = '0.0.0.0:8000'

# 日志
loglevel = 'debug' if dev else 'info'
accesslog = "./log/access.log"
errorlog = "./log/debug.log"
pidfile = "log/gunicorn.pid"

# 启动的进程数
daemon = not dev  # 开启后台
workers = multiprocessing.cpu_count() * 2 + 1
threads = 1
worker_class = 'gevent'  # -k gevent
x_forwarded_for_header = 'X-FORWARDED-FOR'

if __name__ == '__main__':
    os.system("gunicorn -c gun.py flask_app:app")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : model_update
# @Time         : 2019-08-29 16:58
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 
import os
from sanic import Sanic
from sanic.response import html, json, redirect, text, file, file_stream
from sanic.request import Request, File

app = Sanic(__name__)
model_map = {}
@app.route("/update", methods=['GET', 'POST'])
async def update(request):
    global n
    n = len(open("./new_tree.yml").read())
    return text('OK')

@app.route("/files", methods=['GET', 'POST'])
async def post_json(request):

    test_file = request.files.get('file')

    basepath = os.path.dirname(__file__)
    file_path = os.path.join(basepath, './', test_file.name)
    with open(file_path, 'wb') as f:
        f.write(test_file.body)

    return redirect('/update')

from iapp import App

_app = App()
_app.app = app

def predict(**kwargs):
    return n

_app.add_route('/model', predict)

_app.run()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : run_gunicorn
# @Time         : 2019-11-21 14:39
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


import re
import sys

from gunicorn.app.wsgiapp import run

if __name__ == '__main__':
    sys.argv[0] = re.sub(r'(-script\.pyw|\.exe)?$', '', sys.argv[0])
    sys.exit(run())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-Python.
# @File         : demo
# @Time         : 2019-08-15 10:20
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  :
import time
import logging
from datetime import datetime, timedelta
from apscheduler.schedulers.background import BackgroundScheduler

scheduler = BackgroundScheduler()

dic = {}


@scheduler.scheduled_job('interval', seconds=10, next_run_time=datetime.today() + timedelta(seconds=15))
def task():
    """更新变量"""
    logging.warning('Tick! The time is: %s' % time.ctime())
    time.sleep(5)
    dic['n'] = logging
    print('dic', dic)


scheduler.start()
while not dic: # 直到 dic不为空结束
    time.sleep(1)
    print(time.ctime())
    print(dic)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : main
# @Time         : 2019-08-30 17:31
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


import os

os.environ['--models'] = '/Users/yuanjie/Desktop/Projects/Python/tql-App/examples/fds/models'
os.environ['--flag'] = '/Users/yuanjie/Desktop/Projects/Python/tql-App/examples/fds'
flag = __import__('hotflag').flag

from iapp import App
from examples.fds.update import model2transformer

app = App()


def predict(**kwargs):
    model_name = kwargs["model_name"]  # sklearn_lr_demo.model
    (predict, feature_transform) = model2transformer.get(model_name)
    X = feature_transform(**kwargs)  # 二维数组
    return predict(X)


app.add_route('/deploy', predict, methods="POST", flag=flag)
app.run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : upload_sanci
# @Time         : 2019-11-29 13:12
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


import os
from sanic import Sanic
from sanic.response import redirect, html

app = Sanic()


@app.route('/', methods=['POST', 'GET'])
async def upload(request):
    if request.method == 'POST':
        f = request.files.get("file")
        basepath = os.path.dirname(__file__)
        upload_path = os.path.join(basepath, 'static', f.name)
        print(f.name)
        print(f.type)
        print(f.body)
        with open(upload_path, 'wb') as fw:
            fw.write(f.body)
        return redirect(app.url_for('upload'))
    return html("""
        <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <title>Title</title>
    </head>
    <body>
      <h1>文件上传</h1>
      <form action="" enctype='multipart/form-data' method='POST'>
        <input type="file" name="file">
        <input type="submit" value="上传">
      </form>
    </body>
    </html>
    """)


if __name__ == "__main__":
    app.run(host="0.0.0.0", port=9000)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-Python.
# @File         : upload
# @Time         : 2019-08-29 11:43
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  :


"""
https://www.jianshu.com/p/bc95b1e90129?utm_campaign=maleskine&utm_content=note&utm_medium=seo_notes&utm_source=recommendation
"""

import os
from sanic import Sanic, response
from sanic.response import html, json, redirect, text, raw, file, file_stream

app = Sanic()


@app.route('/<file_name>')
async def handle_request(request, file_name):
    """http://0.0.0.0:9000/baidu.png"""

    print(file_name)
    try:
        return await file_stream(f'./{file_name}')  # file(f'./{file}') # 返回字符串 = open('file_name').read()
    except Exception as e:
        print(e)
        return text(os.popen("ls").read())


@app.route("/raw")
async def get_raw(request):
    """访问此接口后，将会立即下载一个名为raw的文件，里面包含内容 it is raw data"""
    return raw(b"it is raw data")


@app.route("/redirect")
async def get_redirect(request):
    """重定向"""
    return redirect("/raw")


@app.route("/streaming")
async def index(request):
    async def streaming_fn(response):
        response.write('foo')
        response.write('bar')

    return response.stream(streaming_fn, content_type='text/plain')


app.run(host="0.0.0.0", port=9000, debug=True, auto_reload=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : app_raw
# @Time         : 2019-08-30 14:15
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  :


from sanic import Sanic, response


app = Sanic()

@app.route('/')
async def index(request):
    return response.text("OK")

debug = {'DEBUG': False}

@app.route('/debug')
async def f(request):
    print(request.args.get('debug', 1))
    debug['DEBUG'] = True if request.args.get('debug') == "1" else False
    debug.update(**request.args)
    print(debug['DEBUG'])

    return response.json(debug)

app.run()












#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : schedulerr
# @Time         : 2019-11-20 17:44
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import time
from datetime import datetime
import os
from apscheduler.schedulers.background import BackgroundScheduler
from apscheduler.schedulers.blocking import BlockingScheduler
from apscheduler.schedulers.asyncio import BaseScheduler

# scheduler = BlockingScheduler()
scheduler = BackgroundScheduler()


@scheduler.scheduled_job('interval', seconds=3)
def tick():
    v = time.ctime()
    os.system(f"echo {v} >> /Users/yuanjie/Desktop/Projects/Python/tql-App/log.txt")
    print('Tick! The time is: %s' % datetime.now())




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : Predictor
# @Time         : 2019-08-29 19:04
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import joblib


class ModelPredictor(object):

    def __init__(self):
        pass

    def predictor(self, filename, model_type='sklearn'):
        """

        :param kwargs:
        :return:
        """
        return self.__getattribute__(f"model_{model_type}")(filename)

    def model_sklearn(self, filename):
        return joblib.load(filename).predict_proba

    def model_keras(self, filename):
        pass

    def model_tensorflow(self, filename):
        pass


if __name__ == '__main__':
    filename = "/Users/yuanjie/Desktop/Projects/Python/tql-App/examples/fds/models/sklearn_lr_demo.model"

    ModelPredictor().predictor(filename)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : template_loader
# @Time         : 2019-08-15 13:19
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from jinja2 import Environment, PackageLoader, select_autoescape, Template

from pathlib import Path

print(list())


class Templates(object):

    def __init__(self):
        # Load the template environment with async support
        self.template_env = Environment(
            loader=PackageLoader('iapp'),  # 所需文件
            autoescape=select_autoescape(),
            enable_async=True
        )

    def load(self):
        _ = {html.name[:-5]: self.template_env.get_template(html.name) for html in self.htmls}
        return _

    @property
    def htmls(self):
        return Path().absolute().parent.joinpath("templates").glob("*.html")


if __name__ == '__main__':
    print(Templates().load())


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : ocr_demo
# @Time         : 2020/11/4 6:00 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


# https://github.com/PaddlePaddle/PaddleOCR/blob/develop/doc/doc_ch/whl.md
from paddleocr import PaddleOCR, draw_ocr
# Paddleocr目前支持中英文、英文、法语、德语、韩语、日语，可以通过修改lang参数进行切换
# 参数依次为`ch`, `en`, `french`, `german`, `korean`, `japan`。
ocr = PaddleOCR(use_angle_cls=True, lang="ch") # need to run only once to download and load model into memory
img_path = '/Users/yuanjie/Desktop/image.png'
result = ocr.ocr(img_path, cls=True)
for line in result:
    print(line)




from tql.pipe import *
rs = [img_path]*100 | xThreadPoolExecutor(lambda p: ocr.ocr(p, cls=True), 10)

print(list(rs))


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : demo
# @Time         : 2019-12-10 20:05
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


import logging

from loguru import logger

from sanic import Sanic
from sanic.response import json


logging.getLogger("sanic.root").handlers.clear()
trace = logger.add('./runtime_{time}.log',
                   rotation="100 MB",
                   retention='3 days',
                   encoding="utf-8",
                   backtrace=True,
                   diagnose=True)
from sanic import log
# logger = logging.getLogger("sanic.root")
# error_logger = logging.getLogger("sanic.error")
# access_logger = logging.getLogger("sanic.access")
log.logger = logger

# Redirect all logging to loguru
class InterceptHandler(logging.Handler):
    def emit(self, record):
        # Retrieve context where the logging call occurred, this happens to be in the 6th frame upward
        logger_opt = logger.opt(depth=6, exception=record.exc_info)
        logger_opt.log(record.levelno, record.getMessage())

# logger.remove()
logging.basicConfig(handlers=[InterceptHandler()], level=0)

app = Sanic()





@app.route('/')
async def test(request):
    return json({'hello': 'world'})


if __name__ == '__main__':
    app.run(host='0.0.0.0', port=8000)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : ocr_app
# @Time         : 2020/11/4 4:05 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


import os
import numpy as np
from iapp import App
from paddleocr import PaddleOCR

ocr = PaddleOCR(use_angle_cls=True, lang="ch")


def get_ocr_result(**kwargs):
    results = []
    image_urls = kwargs.get('image_urls', [])

    for image_url in image_urls:
        os.system(f"wget {image_url} -O image")
        result = ocr.ocr('image', cls=True) # todo

        results.append(result)
    return eval(str(results))

app_ = App()
app_.add_route('/ocr', get_ocr_result, method="POST")

app = app_.app
if __name__ == '__main__':

    # app.run(port=9955, debug=False, reload=False)
    app_.run(f"{app_.app_file_name(__file__)}", port=9955, debug=False, reload=False)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-Python.
# @File         : demo
# @Time         : 2019-08-15 10:20
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  :
import logging
from datetime import datetime

import values
import threading
import do
from iapp import App
import time

model_map = {}

import schedule
import time

import asyncio

d = {}

# async def task():
#     global d
#     while 1:
#         await asyncio.sleep(3)
#         d['t'] = time.ctime()
#         print(d)

# # 调度
# import asyncio
#
# async def task_sleep():
#     while 1:
#         print('sleep before')
#         print(os.popen("ls").read())
#         await asyncio.sleep(5)
#         os.system("rm log.txt")
#         print('sleep after')
#         print(os.popen("ls").read())

from apscheduler.schedulers.background import BackgroundScheduler

scheduler = BackgroundScheduler()


@scheduler.scheduled_job('interval', seconds=3)
async def task():
    logging.warning('Tick! The time is: %s' % datetime.now())
    d['t'] = time.ctime()
    print(d)


scheduler.start()


def update(**kwargs):
    time.sleep(10)

    model_map.update(kwargs)

    return model_map


f1 = lambda **kwargs: model_map
f2 = lambda **kwargs: d


def api(**kwargs):
    print(kwargs)
    print(kwargs.get('method')[0])
    a = eval(kwargs.get('method')[0])(**kwargs)
    return a


##############

app = App()

# app.app.add_task(task())

# update
app.add_route("/update", update, time=time.ctime())

app.add_route("/f1", f1, time=time.ctime())

app.add_route("/f2", f2, time=time.ctime())

app.add_route("/api", api, time=time.ctime())

app.run(workers=1, debug=True, access_log=True, port=9955)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : nlp_app
# @Time         : 2020/11/4 10:24 上午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from iapp import App
import jieba.analyse  as ja

app = App()
app.add_route('/get', lambda **kwargs: ja.tfidf(kwargs.get('text', '')), method="GET", result_key="keywords")
app.run(port=9955, debug=False, reload=False)






#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : example
# @Time         : 2019-08-08 14:30
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import sys
import time
import logging
import jieba
from iapp import App
from iapp.scheduler import Scheduler

# PC

d = 2

def task():
    global d
    d = d - 1
    print(d, 1 / d)

    logging.warning(time.ctime())

    global dt
    dt = time.ctime()
    return dt


scheduler = Scheduler()
scheduler.add_job(task, seconds=10)
scheduler.start()

dt = task()
# Api
update = lambda **kwargs: dt
pred1 = lambda **kwargs: kwargs['x'] + kwargs['y']
pred2 = lambda x=1, y=1: x - y
pred3 = lambda text='小米是家不错的公司': jieba.lcut(text)

app = App()
app.add_route("/", update, version="1")
app.add_route("/", update, methods="POST")

app.add_route("/f1", pred1, version="1")
app.add_route("/f2", pred2, version="2")
if __name__ == '__main__':
    app.run(debug=True, port=8899)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : app_run
# @Time         : 2020/11/5 4:48 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  :
"""
'console_scripts': [
    'app-run=iapp.app_run.run:run'
]
"""
import os
import fire
from pathlib import Path
from iapp.utils import get_module_path


class AppRun(object):
    """doc"""

    def __init__(self, **kwargs):
        """

        :param arg:
        """
        self._apps_path = Path(get_module_path('../apps', __file__))

    def apps_list(self):
        return list(self._apps_path.glob('*app.py'))

    def app_run(self, app_name):
        app_file = list(self._apps_path.glob(f'*{app_name}*'))
        return os.system(f"python {app_file[0]}")


def cli():
    fire.Fire(AppRun)


if __name__ == '__main__':
    print(AppRun().apps_list())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : fastApiDemo
# @Time         : 2020/10/22 4:22 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from iapp import App

func = lambda **kwargs: kwargs

app_ = App()

app_.add_route("/demo", func, version=1)
app_.add_route("/demo_", func)

app = app_.app

if __name__ == '__main__':
    # app.run(port=1234)
    app_.run(app_.app_file_name(__file__), port=4321, debug=True, reload=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : flask_upload
# @Time         : 2019-11-29 13:22
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

from flask import Flask, request, redirect, url_for
import os

app = Flask(__name__)

@app.route('/upload', methods=['POST', 'GET'])
def upload():
    if request.method == 'POST':
        f = request.files['file']
        basepath = os.path.dirname(__file__)
        upload_path = os.path.join(basepath, 'static', f.filename)
        f.save(upload_path)
        return redirect(url_for('upload'))
    # return render_template('./upload.html')
    return '''
    <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <title>Title</title>
    </head>
    <body>
      <h1>文件上传</h1>
      <form action="" enctype='multipart/form-data' method='POST'>
        <input type="file" name="file">
        <input type="submit" value="上传">
      </form>
    </body>
    </html>
    '''


if __name__ == '__main__':
    app.run(host="0.0.0.0", port=9001, debug=True)
